#[non_exhaustive]pub enum AgentStreamEvent {
Chunk(StreamChunk),
Final(AgentResponse),
}Expand description
Emits provisional stream chunks followed by one authoritative committed response.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Chunk(StreamChunk)
Provisional content, tool, state, or error information emitted during execution.
Final(AgentResponse)
Authoritative response emitted after successful root-turn finalization.