pub enum SecurityCheckResult {
Allow,
Block {
reason: String,
},
Warn {
message: String,
},
RequireConfirmation {
message: String,
},
Unavailable {
reason: String,
},
}Expand description
Security decision returned by the tool security engine.
Variants
Implementations
Sourceimpl SecurityCheckResult
impl SecurityCheckResult
Sourcepub fn is_allowed(&self) -> bool
pub fn is_allowed(&self) -> bool
Returns true when execution may continue without blocking.
Sourcepub fn is_blocked(&self) -> bool
pub fn is_blocked(&self) -> bool
Returns true when execution must not invoke the tool.
Sourcepub fn outcome(&self) -> PermissionOutcome
pub fn outcome(&self) -> PermissionOutcome
Converts the security result to a stable permission outcome.
Sourcepub fn requires_approval(&self) -> bool
pub fn requires_approval(&self) -> bool
Returns true when a human approval request is required.
Returns true when the tool or required host policy is unavailable.