pub enum TransitionTiming {
PostResponse,
PreResponse,
Parallel,
}Variants
PostResponse
Evaluate after the assistant response is available.
PreResponse
Evaluate before main response generation when the route is response independent.
Parallel
Evaluate in parallel with a draft response when explicitly enabled.