pub struct ResolvedTemplate {
pub content: String,
pub description: Option<String>,
pub variables: Option<HashMap<String, String>>,
}Expand description
A spawner template with its raw content and extracted metadata.
Fields
content: StringRaw Jinja2 template string for rendering.
description: Option<String>Template description extracted from the description: field.
variables: Option<HashMap<String, String>>Variable name -> description map extracted from metadata.template.variables.
Implementations
Sourceimpl ResolvedTemplate
impl ResolvedTemplate
Sourcepub fn from_content(content: impl Into<String>) -> ResolvedTemplate
pub fn from_content(content: impl Into<String>) -> ResolvedTemplate
Create a ResolvedTemplate from a plain content string with no metadata.