pub struct ProcessProcessor { /* private fields */ }Expand description
Executes configured input and output process stages.
Implementations
Sourceimpl ProcessProcessor
impl ProcessProcessor
pub fn new(config: ProcessConfig) -> ProcessProcessor
pub fn with_llm_registry(self, registry: Arc<LLMRegistry>) -> ProcessProcessor
Sourcepub fn with_stage_observer(
self,
observer: Arc<dyn ProcessStageObserver>,
) -> ProcessProcessor
pub fn with_stage_observer( self, observer: Arc<dyn ProcessStageObserver>, ) -> ProcessProcessor
Attaches a runtime observer used to instrument each process stage.
Sourcepub fn input_purpose_hint(&self) -> ProcessPurposeHint
pub fn input_purpose_hint(&self) -> ProcessPurposeHint
Returns the first meaningful purpose hint for the input pipeline.
Sourcepub fn output_purpose_hint(&self) -> ProcessPurposeHint
pub fn output_purpose_hint(&self) -> ProcessPurposeHint
Returns the first meaningful purpose hint for the output pipeline.
pub async fn process_input( &self, input: &str, ) -> Result<ProcessData, AgentError>
pub async fn process_output( &self, output: &str, input_context: &HashMap<String, Value>, ) -> Result<ProcessData, AgentError>