pub struct RecoveryManager { /* private fields */ }Implementations
Sourceimpl RecoveryManager
impl RecoveryManager
Sourcepub fn new(config: ErrorRecoveryConfig) -> RecoveryManager
pub fn new(config: ErrorRecoveryConfig) -> RecoveryManager
Creates a validated recovery manager and panics when host configuration is invalid.
Sourcepub fn try_new(
config: ErrorRecoveryConfig,
) -> Result<RecoveryManager, AgentError>
pub fn try_new( config: ErrorRecoveryConfig, ) -> Result<RecoveryManager, AgentError>
Creates a validated recovery manager with a recoverable configuration error.
pub fn config(&self) -> &ErrorRecoveryConfig
Sourcepub async fn with_retry<T, E, F, Fut>(
&self,
operation_name: &str,
retry_config: Option<&RetryConfig>,
operation: F,
) -> Result<T, RecoveryError>
pub async fn with_retry<T, E, F, Fut>( &self, operation_name: &str, retry_config: Option<&RetryConfig>, operation: F, ) -> Result<T, RecoveryError>
Execute operation with retry logic
Sourcepub fn get_tool_config(&self, tool_id: &str) -> &ToolRetryConfig
pub fn get_tool_config(&self, tool_id: &str) -> &ToolRetryConfig
Returns the tool-specific retry policy or the complete default policy.
Sourcepub fn get_tool_timeout(&self, tool_id: &str) -> Option<u64>
pub fn get_tool_timeout(&self, tool_id: &str) -> Option<u64>
Returns the timeout from the complete retry policy selected for this tool.