RuntimeAgent

Struct RuntimeAgent 

pub struct RuntimeAgent { /* private fields */ }

Implementations

Source

impl RuntimeAgent

pub fn new( info: AgentInfo, llm_registry: Arc<LLMRegistry>, memory: Arc<dyn Memory>, tools: Arc<ToolRegistry>, skills: Vec<SkillDefinition>, system_prompt: String, max_iterations: u32, ) -> RuntimeAgent

pub fn with_declared_tool_ids(self, ids: Option<Vec<String>>) -> RuntimeAgent

pub fn with_storage_config(self, config: StorageConfig) -> RuntimeAgent

pub fn with_storage(self, storage: Arc<dyn AgentStorage>) -> RuntimeAgent

pub fn with_reasoning(self, config: ReasoningConfig) -> RuntimeAgent

pub fn with_reflection(self, config: ReflectionConfig) -> RuntimeAgent

pub fn reasoning_config(&self) -> &ReasoningConfig

pub fn reflection_config(&self) -> &ReflectionConfig

pub fn with_persona(self, manager: Arc<PersonaManager>) -> RuntimeAgent

pub fn persona_manager(&self) -> Option<&Arc<PersonaManager>>

pub fn with_disambiguation(self, config: DisambiguationConfig) -> RuntimeAgent

pub fn disambiguation_manager(&self) -> Option<&DisambiguationManager>

pub fn has_disambiguation(&self) -> bool

pub async fn init_storage(&self) -> Result<(), AgentError>

pub fn storage(&self) -> Option<Arc<dyn AgentStorage>>

pub fn storage_config(&self) -> &StorageConfig

pub fn spawner(&self) -> Option<&Arc<AgentSpawner>>

Returns the spawner if configured via a spawner: YAML section.

pub fn spawner_registry(&self) -> Option<&Arc<AgentRegistry>>

Returns the agent registry if configured via a spawner: YAML section.

pub fn has_spawner(&self) -> bool

pub fn with_spawner_handles( self, spawner: Arc<AgentSpawner>, registry: Arc<AgentRegistry>, ) -> RuntimeAgent

pub fn with_hooks(self, hooks: Arc<dyn AgentHooks>) -> RuntimeAgent

pub fn with_parallel_tools(self, config: ParallelToolsConfig) -> RuntimeAgent

pub fn with_streaming(self, config: StreamingConfig) -> RuntimeAgent

pub fn with_hitl( self, engine: HITLEngine, handler: Arc<dyn ApprovalHandler>, ) -> RuntimeAgent

pub fn with_max_context_tokens(self, tokens: u32) -> RuntimeAgent

pub fn with_memory_token_budget(self, budget: MemoryTokenBudget) -> RuntimeAgent

pub fn with_recovery_manager(self, manager: RecoveryManager) -> RuntimeAgent

pub fn with_tool_security(self, engine: ToolSecurityEngine) -> RuntimeAgent

pub fn with_process_processor(self, processor: ProcessProcessor) -> RuntimeAgent

pub fn with_state_machine( self, state_machine: Arc<StateMachine>, evaluator: Arc<dyn TransitionEvaluator>, ) -> RuntimeAgent

pub fn with_context_manager(self, manager: Arc<ContextManager>) -> RuntimeAgent

pub fn register_message_filter( &self, name: impl Into<String>, filter: Arc<dyn MessageFilter>, )

pub fn set_context(&self, key: &str, value: Value) -> Result<(), AgentError>

pub fn update_context(&self, path: &str, value: Value) -> Result<(), AgentError>

pub fn get_context(&self) -> HashMap<String, Value>

pub fn remove_context(&self, key: &str) -> Option<Value>

pub async fn refresh_context(&self, key: &str) -> Result<(), AgentError>

pub fn register_context_provider( &self, name: &str, provider: Arc<dyn ContextProvider>, )

pub fn current_state(&self) -> Option<String>

pub async fn transition_to(&self, state: &str) -> Result<(), AgentError>

pub fn state_history(&self) -> Vec<StateTransitionEvent>

pub async fn save_state(&self) -> Result<AgentSnapshot, AgentError>

pub async fn save_state_full(&self) -> Result<AgentSnapshot, AgentError>

Save state including spawned agents manifest for session persistence.

pub async fn restore_state( &self, snapshot: AgentSnapshot, ) -> Result<(), AgentError>

pub async fn save_to( &self, storage: &dyn AgentStorage, session_id: &str, ) -> Result<(), AgentError>

pub async fn load_from( &self, storage: &dyn AgentStorage, session_id: &str, ) -> Result<bool, AgentError>

pub async fn save_session(&self, session_id: &str) -> Result<(), AgentError>

pub async fn load_session(&self, session_id: &str) -> Result<bool, AgentError>

pub async fn delete_session(&self, session_id: &str) -> Result<(), AgentError>

pub async fn list_sessions(&self) -> Result<Vec<String>, AgentError>

pub fn info(&self) -> AgentInfo

pub fn skills(&self) -> &[SkillDefinition]

pub async fn reset(&self) -> Result<(), AgentError>

pub fn max_context_tokens(&self) -> u32

pub fn llm_registry(&self) -> &Arc<LLMRegistry>

pub fn state_machine(&self) -> Option<&Arc<StateMachine>>

pub fn context_manager(&self) -> &Arc<ContextManager>

pub fn tool_call_history(&self) -> Vec<ToolCallRecord>

pub fn memory_token_budget(&self) -> Option<&MemoryTokenBudget>

pub fn parallel_tools_config(&self) -> &ParallelToolsConfig

pub fn streaming_config(&self) -> &StreamingConfig

pub fn hooks(&self) -> &Arc<dyn AgentHooks>

pub fn hitl_engine(&self) -> Option<&HITLEngine>

pub fn approval_handler(&self) -> &Arc<dyn ApprovalHandler>

pub async fn check_state_hitl( &self, from: Option<&str>, to: &str, ) -> Result<bool, AgentError>

pub async fn chat_stream<'a>( &'a self, input: &'a str, ) -> Result<Pin<Box<dyn Stream<Item = StreamChunk> + Send + 'a>>, AgentError>

Stream a chat response with real-time updates